summaryrefslogtreecommitdiffstats
path: root/src/webquerygooglescholar.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/webquerygooglescholar.h')
-rw-r--r--src/webquerygooglescholar.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/webquerygooglescholar.h b/src/webquerygooglescholar.h
index 6d9065a..20003fd 100644
--- a/src/webquerygooglescholar.h
+++ b/src/webquerygooglescholar.h
@@ -20,8 +20,8 @@
#ifndef KBIBTEXWEBQUERYGOOGLESCHOLAR_H
#define KBIBTEXWEBQUERYGOOGLESCHOLAR_H
-#include <qstringlist.h>
-#include <qbuffer.h>
+#include <ntqstringlist.h>
+#include <ntqbuffer.h>
#include <kurl.h>
@@ -37,7 +37,7 @@ namespace KBibTeX
{
Q_OBJECT
public:
- WebQueryGoogleScholarWidget( QWidget *parent, const char *name = 0 );
+ WebQueryGoogleScholarWidget( TQWidget *parent, const char *name = 0 );
};
/**
@@ -47,14 +47,14 @@ namespace KBibTeX
{
Q_OBJECT
public:
- WebQueryGoogleScholar( QWidget* parent );
+ WebQueryGoogleScholar( TQWidget* parent );
virtual ~WebQueryGoogleScholar();
void query();
- QString title();
- QString disclaimer();
- QString disclaimerURL();
+ TQString title();
+ TQString disclaimer();
+ TQString disclaimerURL();
WebQueryWidget *widget();
@@ -62,7 +62,7 @@ namespace KBibTeX
void cancelQuery();
private slots:
- void slotData( KIO::Job *, const QByteArray &data )
+ void slotData( KIO::Job *, const TQByteArray &data )
{
m_transferJobBuffer->writeBlock( data.data(), data.size() );
};
@@ -80,30 +80,30 @@ namespace KBibTeX
WebQueryGoogleScholarWidget *m_widget;
bool m_abort;
- QString m_searchTerm;
+ TQString m_searchTerm;
int m_numberOfResults;
BibTeX::FileImporterBibTeX *m_importer;
bool m_originalEnableCookies;
bool m_originalSessionCookies;
- QMap <QString, QString> m_originalCookieMap;
- QString m_originalCookieGlobalAdvice;
+ TQMap <TQString, TQString> m_originalCookieMap;
+ TQString m_originalCookieGlobalAdvice;
KIO::TransferJob *m_transferJob;
- QBuffer *m_transferJobBuffer;
+ TQBuffer *m_transferJobBuffer;
/** load KDE's cookie configuration, store values, and reset with Google-friendly values */
void readAndChangeConfig();
/** restore previous configuration values by saving old cookie configuration */
void restoreConfig();
- /** extract text from a QBuffer object */
- QString textFromBuffer( QBuffer *buffer );
+ /** extract text from a TQBuffer object */
+ TQString textFromBuffer( TQBuffer *buffer );
/** parse HTML code and get all key-value pairs from <input..> and <select><option ...></select> */
- QMap <QString, QString> evalFormFields( const QString &htmlCode );
+ TQMap <TQString, TQString> evalFormFields( const TQString &htmlCode );
/** glue together URL from key-value pairs in form */
- QString formFieldsToUrl( const QString &prefix, const QMap<QString, QString> &keyValues );
+ TQString formFieldsToUrl( const TQString &prefix, const TQMap<TQString, TQString> &keyValues );
};
}